From 5644ac41c42fde4a4434131e45110aa1e909e0b2 Mon Sep 17 00:00:00 2001
From: Mauro Aranda <maurooaranda@gmail.com>
Date: Sat, 30 Jan 2021 07:47:34 +0100
Subject: [PATCH] Add source to sgml-empty-tags

* lisp/textmodes/sgml-mode.el (html-mode): Add "source" as an empty
tag to fix indentation when this element is present (bug#46181).
---
 lisp/textmodes/sgml-mode.el | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/lisp/textmodes/sgml-mode.el b/lisp/textmodes/sgml-mode.el
index 8465e82b02a..c50c544cb54 100644
--- a/lisp/textmodes/sgml-mode.el
+++ b/lisp/textmodes/sgml-mode.el
@@ -2402,9 +2402,9 @@ To work around that, do:
 
   (setq-local sgml-empty-tags
 	      ;; From HTML-4.01's loose.dtd, parsed with
 	      ;; `sgml-parse-dtd', plus manual addition of "wbr".
 	      '("area" "base" "basefont" "br" "col" "frame" "hr" "img" "input"
-		"isindex" "link" "meta" "param" "wbr"))
+                "isindex" "link" "meta" "source" "param" "wbr"))
   (setq-local sgml-unclosed-tags
 	      ;; From HTML-4.01's loose.dtd, parsed with `sgml-parse-dtd'.
 	      '("body" "colgroup" "dd" "dt" "head" "html" "li" "option"
@@ -2402,9 +2402,9 @@ To work around that, do:
   (setq-local sgml-empty-tags
 	      ;; From HTML-4.01's loose.dtd, parsed with
-	      ;; `sgml-parse-dtd', plus manual addition of "wbr".
+              ;; `sgml-parse-dtd', plus manual additions of "source" and "wbr".
 	      '("area" "base" "basefont" "br" "col" "frame" "hr" "img" "input"
-- 
2.39.5